==> jc-1.4.0.tar.gz: gnu/java/awt/color/GrayProfileConverter.h <==
// public class gnu.java.awt.color.GrayProfileConverter

// class file dependencies
// @dep_class 461a82210aca66e7 gnu_java_awt_color_GrayProfileConverter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_GrayProfileConverter_H_
#define _JC_gnu_java_awt_color_GrayProfileConverter_H_

// Forward structure declarations
struct _jc_gnu_java_awt_color_ColorLookUpTable$object;
struct _jc_gnu_java_awt_color_GrayScaleConverter$object;
struct _jc_gnu_java_awt_color_ToneReproductionCurve$object;
struct _jc_java_awt_color_ICC__5fProfileGray$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$sub_refs	_jc_gnu_java_awt_color_GrayProfileConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$sub_nonrefs	_jc_gnu_java_awt_color_GrayProfileConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$refs	_jc_gnu_java_awt_color_GrayProfileConverter$refs;
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$nonrefs	_jc_gnu_java_awt_color_GrayProfileConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$object	_jc_gnu_java_awt_color_GrayProfileConverter$object;

typedef const struct _jc_gnu_java_awt_color_GrayProfileConverter$vmethods	_jc_gnu_java_awt_color_GrayProfileConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_GrayProfileConverter$vtable	_jc_gnu_java_awt_color_GrayProfileConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_GrayProfileConverter$vtype	_jc_gnu_java_awt_color_GrayProfileConverter$vtype;

// Constructors
extern void _jc_gnu_java_awt_color_GrayProfileConverter$method$_init$51b89f154875c876(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_java_awt_color_ICC__5fProfileGray$object *);

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_GrayProfileConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_GrayProfileConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_GrayProfileConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_GrayProfileConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_GrayProfileConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_GrayProfileConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_GrayProfileConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_GrayProfileConverter$method_info$toRGB$8e7372c09e81aa9c;

// Virtual methods structure
struct _jc_gnu_java_awt_color_GrayProfileConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *);
};

// Vtable
struct _jc_gnu_java_awt_color_GrayProfileConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_GrayProfileConverter$vmethods	gnu_java_awt_color_GrayProfileConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_GrayProfileConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_GrayProfileConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_GrayProfileConverter$sub_refs {
	struct _jc_gnu_java_awt_color_GrayScaleConverter$object	*gc;
	struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	*trc;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*toPCS;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*fromPCS;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_GrayProfileConverter$refs {
    _jc_gnu_java_awt_color_GrayProfileConverter$sub_refs	gnu_java_awt_color_GrayProfileConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_GrayProfileConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_GrayProfileConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_GrayProfileConverter$sub_nonrefs	gnu_java_awt_color_GrayProfileConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_GrayProfileConverter$object {
	_jc_gnu_java_awt_color_GrayProfileConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_GrayProfileConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_GrayProfileConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_GrayProfileConverter$vtype _jc_gnu_java_awt_color_GrayProfileConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_GrayProfileConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_GrayProfileConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_GrayProfileConverter_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/color/GrayProfileConverter.h <==
// public class gnu.java.awt.color.GrayProfileConverter

// class file dependencies
// @dep_class 5d1ef1df32e8b1f3 gnu_java_awt_color_GrayProfileConverter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_GrayProfileConverter_H_
#define _JC_gnu_java_awt_color_GrayProfileConverter_H_

// Forward structure declarations
struct _jc_gnu_java_awt_color_ColorLookUpTable$object;
struct _jc_gnu_java_awt_color_GrayScaleConverter$object;
struct _jc_gnu_java_awt_color_ToneReproductionCurve$object;
struct _jc_java_awt_color_ICC__5fProfileGray$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$sub_refs	_jc_gnu_java_awt_color_GrayProfileConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$sub_nonrefs	_jc_gnu_java_awt_color_GrayProfileConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$refs	_jc_gnu_java_awt_color_GrayProfileConverter$refs;
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$nonrefs	_jc_gnu_java_awt_color_GrayProfileConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_GrayProfileConverter$object	_jc_gnu_java_awt_color_GrayProfileConverter$object;

typedef const struct _jc_gnu_java_awt_color_GrayProfileConverter$vmethods	_jc_gnu_java_awt_color_GrayProfileConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_GrayProfileConverter$vtable	_jc_gnu_java_awt_color_GrayProfileConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_GrayProfileConverter$vtype	_jc_gnu_java_awt_color_GrayProfileConverter$vtype;

// Constructors
extern void _jc_gnu_java_awt_color_GrayProfileConverter$method$_init$51b89f154875c876(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_java_awt_color_ICC__5fProfileGray$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_GrayProfileConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_GrayProfileConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_GrayProfileConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_GrayProfileConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_GrayProfileConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_GrayProfileConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_GrayProfileConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_GrayProfileConverter$method_info$toRGB$8e7372c09e81aa9c;

// Virtual methods structure
struct _jc_gnu_java_awt_color_GrayProfileConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_GrayProfileConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_color_GrayProfileConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_GrayProfileConverter$vmethods	gnu_java_awt_color_GrayProfileConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_GrayProfileConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_GrayProfileConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_GrayProfileConverter$sub_refs {
	struct _jc_gnu_java_awt_color_GrayScaleConverter$object	*gc;
	struct _jc_gnu_java_awt_color_ToneReproductionCurve$object	*trc;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*toPCS;
	struct _jc_gnu_java_awt_color_ColorLookUpTable$object	*fromPCS;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_GrayProfileConverter$refs {
    _jc_gnu_java_awt_color_GrayProfileConverter$sub_refs	gnu_java_awt_color_GrayProfileConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_GrayProfileConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_GrayProfileConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_GrayProfileConverter$sub_nonrefs	gnu_java_awt_color_GrayProfileConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_GrayProfileConverter$object {
	_jc_gnu_java_awt_color_GrayProfileConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_GrayProfileConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_GrayProfileConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_GrayProfileConverter$vtype _jc_gnu_java_awt_color_GrayProfileConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_GrayProfileConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_GrayProfileConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_GrayProfileConverter_H_ */
